@@ -1,7 +1,6 @@
 from .goatpie import GoatPie
 
-
 __all__ = [
     # Main class
-    'GoatPie',
+    "GoatPie",
 ]
