@@ -14,8 +14,7 @@ class GoatBar(Widget):
     Textual widget for 'multiple_bar' plot created with 'plotext'
     """
 
-    def __init__(self, obj, name: Optional[str] = None, limit: int = 14
-    ) -> None:
+    def __init__(self, obj, name: Optional[str] = None, limit: int = 14) -> None:
         """
         Initializes 'GoatBar' instance
 
@@ -33,7 +32,6 @@ class GoatBar(Widget):
         self.obj = obj
         self.limit = limit
 
-
     def render(self) -> Panel:
         """
         Renders 'multiple_bar' plot created with 'plotext'
@@ -47,8 +45,7 @@ class GoatBar(Widget):
         # Define top padding
         spacing = (1, 0, 0, 0)
 
-        return Padding(Panel(renderable, title='Last {} days'.format(self.limit), padding=spacing), spacing)
-
+        return Padding(Panel(renderable, title="Last {} days".format(self.limit), padding=spacing), spacing)
 
     # TODO: Update data & rerender
     # async def update(self, renderable: RenderableType) -> None:
