@@ -1,34 +1,51 @@
-import math
 import urllib
 
 import pandas
 import plotext
-
 from rich import box
-from rich.table import Table, Column
+from rich.table import Column, Table
 
 
-def get_domain(url: str) -> str:
+def get_domain(url: str, keep_subdomain: bool = False) -> str:
     """
     Extract domain ('example.com'), quick&dirty
 
     :param url: str Target URL
+    :param keep_subdomain: bool Whether to strip subdomain
 
     :return: str
     """
 
-    # Parse URL & extract its network location
-    netloc = urllib.parse.urlparse(url).netloc
+    # Parse URL
+    parsed = urllib.parse.urlparse(url)
 
-    # Combine last two parts (= domain name & tld)
-    return '.'.join(netloc.split('.')[-2:])
+    # If input is malformed (eg no scheme, like 'example.com') ..
+    if parsed.path == url:
+        # .. prepend scheme & try again
+        parsed = urllib.parse.urlparse("http://{}".format(url))
+
+    # Determine domain
+    # (1) Extract network location
+    # (2) Remove backslashes (eg '\\192.168.X.Y')
+    netloc = parsed.netloc.lstrip("\\")
+
+    # If not keeping subdomain ..
+    if not keep_subdomain:
+        # .. combine its last two parts (= domain name & tld)
+        return ".".join(netloc.split(".")[-2:])
+
+    # .. otherwise keep whole record
+    return netloc
 
 
-def render_stats(obj, width: int, height: int,
-    labels: list = ['Visits', 'Pageviews'],
-    colors: list = ['blue', 'magenta'],
+def render_stats(
+    obj,
+    width: int,
+    height: int,
+    labels: list = ["Visits", "Pageviews"],
+    colors: list = ["blue", "magenta"],
     limit: int = 14,
-    step: int = 100
+    step: int = 100,
 ) -> str:
     """
     Renders visits & pageviews using 'plotext'
@@ -57,19 +74,21 @@ def render_stats(obj, width: int, height: int,
     bar_width = 0.4
 
     # Configure plot
-    plotext.multiple_bar(visits.Day, [visits.Visits, pageviews.Pageviews], label=labels, width=bar_width, marker='hd', color=colors)
+    plotext.multiple_bar(
+        visits.Day, [visits.Visits, pageviews.Pageviews], label=labels, width=bar_width, marker="hd", color=colors
+    )
     plotext.plotsize(width, height)
-    plotext.xlabel('hits / day')
+    plotext.xlabel("hits / day")
     plotext.frame(False)
-    plotext.ticks_color('white')
-    plotext.ticks_style('bold')
+    plotext.ticks_color("white")
+    plotext.ticks_style("bold")
     plotext.xticks([])
     plotext.yticks(range(0, pageviews.Pageviews.max(), step))
 
     return plotext.build()
 
 
-def data2table(data: pandas.DataFrame, title: str = '', colors = ['blue', 'white', 'cyan']) -> Table:
+def data2table(data: pandas.DataFrame, title: str = "", colors=["blue", "white", "cyan"]) -> Table:
     """
     Creates 'rich' table from 'pandas' dataframe
 
@@ -81,15 +100,13 @@ def data2table(data: pandas.DataFrame, title: str = '', colors = ['blue', 'white
     """
 
     # Create header row
-    header = [Column(
-        header=header, justify='right', style=colors[idx]
-    ) for idx, header in enumerate(data.columns)]
+    header = [Column(header=header, justify="right", style=colors[idx]) for idx, header in enumerate(data.columns)]
 
     # Construct table
     table = Table(
         title=title,
-        title_style='bold white',
-        header_style='bold white',
+        title_style="bold white",
+        header_style="bold white",
         show_lines=False,
         box=box.ROUNDED,
         expand=True,
